@@ -20,7 +20,7 @@ use rand_xorshift::XorShiftRng;
 use snarkvm_algorithms::{
     commitment::PedersenCompressedCommitment,
     commitment_tree::*,
-    crh::{BoweHopwoodPedersenCompressedCRH, PedersenSize},
+    crh::BoweHopwoodPedersenCompressedCRH,
     traits::{CommitmentScheme, CRH},
 };
 use snarkvm_curves::{bls12_377::Fr, edwards_bls12::EdwardsProjective as EdwardsBls};
@@ -34,34 +34,24 @@ use crate::{
         commitment_tree::*,
         crh::BoweHopwoodPedersenCompressedCRHGadget,
     },
-    curves::edwards_bls12::EdwardsBlsGadget,
+    curves::edwards_bls12::EdwardsBls12Gadget,
     traits::{
         algorithms::{CRHGadget, CommitmentGadget},
         alloc::AllocGadget,
     },
 };
 
-#[derive(Clone, Debug, PartialEq, Eq, Hash)]
-pub struct CRHWindow;
+const CRH_NUM_WINDOWS: usize = 16;
+const CRH_WINDOW_SIZE: usize = 32;
 
-impl PedersenSize for CRHWindow {
-    const NUM_WINDOWS: usize = 16;
-    const WINDOW_SIZE: usize = 32;
-}
+const COMMITMENT_NUM_WINDOWS: usize = 8;
+const COMMITMENT_WINDOW_SIZE: usize = 32;
 
-#[derive(Clone, Debug, PartialEq, Eq, Hash)]
-pub struct CommitmentWindow;
+pub type H = BoweHopwoodPedersenCompressedCRH<EdwardsBls, CRH_NUM_WINDOWS, CRH_WINDOW_SIZE>;
+pub type HG = BoweHopwoodPedersenCompressedCRHGadget<EdwardsBls, Fr, EdwardsBls12Gadget>;
 
-impl PedersenSize for CommitmentWindow {
-    const NUM_WINDOWS: usize = 8;
-    const WINDOW_SIZE: usize = 32;
-}
-
-pub type H = BoweHopwoodPedersenCompressedCRH<EdwardsBls, CRHWindow>;
-pub type HG = BoweHopwoodPedersenCompressedCRHGadget<EdwardsBls, Fr, EdwardsBlsGadget>;
-
-pub type C = PedersenCompressedCommitment<EdwardsBls, CommitmentWindow>;
-pub type CG = PedersenCompressedCommitmentGadget<EdwardsBls, Fr, EdwardsBlsGadget>;
+pub type C = PedersenCompressedCommitment<EdwardsBls, COMMITMENT_NUM_WINDOWS, COMMITMENT_WINDOW_SIZE>;
+pub type CG = PedersenCompressedCommitmentGadget<EdwardsBls, Fr, EdwardsBls12Gadget>;
 
 /// Generates a valid Merkle tree and verifies the Merkle path witness for each leaf.
 fn generate_merkle_tree<C: CommitmentScheme, H: CRH, R: Rng>(
